==> 1.2.1.tar.gz: core/README.md <==
FuzeWorks - Readme [![pipeline status](http://git.i15.nl/fuzeworks/core/badges/development/pipeline.svg)](http://git.i15.nl/fuzeworks/core/commits/development) [![coverage report](http://git.i15.nl/fuzeworks/core/badges/development/coverage.svg)](http://git.i15.nl/fuzeworks/core/commits/development)
===================

Version 1.2.0

A versatile PHP Framework built to perform.

https://techfuze.net/fuzeworks

Summary
-------

FuzeWorks is a flexible PHP Framework made for the requirements of todays web.
For a summary of features, list of requirements, and installation instructions,
please see the documentation in the ./doc/ folder or at http://techfuze.net/fuzeworks

Copyright
---------

Copyright © 2013 onwards -- TechFuze

Certain libraries are copyrighted by their respective authors;
see the full copyright list for details.

For full copyright information, please see ./doc/copyright.html

License
-------

MIT License

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

Licensing of current contributions
----------------------------------

Beginning on 2018-04-17, new contributions to this codebase are all licensed
under terms compatible with the MIT license.  FuzeWorks is currently
transitioning older code to the MIT License, but work is not yet complete.

Enjoy!
------

TechFuze

==> 1.3.2.tar.gz: core/README.md <==
FuzeWorks - Readme [![pipeline status](http://git.i15.nl/fuzeworks/core/badges/development/pipeline.svg)](http://git.i15.nl/fuzeworks/core/commits/development) [![coverage report](http://git.i15.nl/fuzeworks/core/badges/development/coverage.svg)](http://git.i15.nl/fuzeworks/core/commits/development)
===================

Version 1.2.0

A versatile PHP Framework built to perform.

https://techfuze.net/fuzeworks

Summary
-------

FuzeWorks is a flexible PHP Framework made for the requirements of today's web.
For a summary of features, list of requirements, and installation instructions,
please see the documentation in the ./doc/ folder or at http://techfuze.net/fuzeworks

Copyright
---------

Copyright © 2013 onwards -- TechFuze

Certain libraries are copyrighted by their respective authors;
see the full copyright list for details.

For full copyright information, please see ./doc/copyright.html

License
-------

MIT License

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

Licensing of current contributions
----------------------------------

Beginning on 2018-04-17, new contributions to this codebase are all licensed
under terms compatible with the MIT license.  FuzeWorks is currently
transitioning older code to the MIT License, but work is not yet complete.

Enjoy!
------

TechFuze
